glaze/oat/progress

Oat documentation: https://oat.ink/components/progress/

Progress helpers for linear completion indicators.

Anatomy

Use progress with value and max to show task completion. Typed helpers are available for Int and Float values.

Recipe

import glaze/oat/progress

progress.progress([
  progress.value_int(32),
  progress.max_int(100),
])

References

Values

pub fn max(amount: String) -> attribute.Attribute(msg)
pub fn max_float(amount: Float) -> attribute.Attribute(msg)
pub fn max_int(amount: Int) -> attribute.Attribute(msg)
pub fn progress(
  attrs: List(attribute.Attribute(msg)),
) -> element.Element(msg)
pub fn value(amount: String) -> attribute.Attribute(msg)
pub fn value_float(amount: Float) -> attribute.Attribute(msg)
pub fn value_int(amount: Int) -> attribute.Attribute(msg)
Search Document